@@ -34,9 +34,9 @@ BASE_CONFIGURATION = {
         "groups": {"users": {"gid": 100}, "admin": {"gid": 101}},
     },
     "default_images": {
-        "jupyterhub": "quansight/qhub-jupyterhub:71645f84ec3ebe5fe6aab86fe9b381190ab7645c",
-        "jupyterlab": "quansight/qhub-jupyterlab:71645f84ec3ebe5fe6aab86fe9b381190ab7645c",
-        "dask_worker": "quansight/qhub-dask-worker:71645f84ec3ebe5fe6aab86fe9b381190ab7645c",
+        "jupyterhub": "quansight/qhub-jupyterhub:0a4150d28162c641944e60ae41e04ac96dd2f890",
+        "jupyterlab": "quansight/qhub-jupyterlab:0a4150d28162c641944e60ae41e04ac96dd2f890",
+        "dask_worker": "quansight/qhub-dask-worker:0a4150d28162c641944e60ae41e04ac96dd2f890",
     },
     "storage": {"conda_store": "60Gi", "shared_filesystem": "100Gi"},
     "theme": {
@@ -169,7 +169,7 @@ DEFAULT_PROFILES = {
                 "cpu_guarantee": 0.75,
                 "mem_limit": "4G",
                 "mem_guarantee": "2.5G",
-                "image": "quansight/qhub-jupyterlab:71645f84ec3ebe5fe6aab86fe9b381190ab7645c",
+                "image": "quansight/qhub-jupyterlab:0a4150d28162c641944e60ae41e04ac96dd2f890",
             },
         },
         {
@@ -180,18 +180,18 @@ DEFAULT_PROFILES = {
                 "cpu_guarantee": 1.5,
                 "mem_limit": "8G",
                 "mem_guarantee": "5G",
-                "image": "quansight/qhub-jupyterlab:71645f84ec3ebe5fe6aab86fe9b381190ab7645c",
+                "image": "quansight/qhub-jupyterlab:0a4150d28162c641944e60ae41e04ac96dd2f890",
             },
         },
     ],
     "dask_worker": {
         "Small Worker": {
             "worker_cores_limit": 1,
-            "worker_cores": 1,
+            "worker_cores": 0.75,
             "worker_memory_limit": "4G",
             "worker_memory": "2.5G",
             "worker_threads": 1,
-            "image": "quansight/qhub-dask-worker:71645f84ec3ebe5fe6aab86fe9b381190ab7645c",
+            "image": "quansight/qhub-dask-worker:0a4150d28162c641944e60ae41e04ac96dd2f890",
         },
         "Medium Worker": {
             "worker_cores_limit": 2,
@@ -199,28 +199,45 @@ DEFAULT_PROFILES = {
             "worker_memory_limit": "8G",
             "worker_memory": "5G",
             "worker_threads": 2,
-            "image": "quansight/qhub-dask-worker:71645f84ec3ebe5fe6aab86fe9b381190ab7645c",
+            "image": "quansight/qhub-dask-worker:0a4150d28162c641944e60ae41e04ac96dd2f890",
         },
     },
 }
 
 DEFAULT_ENVIRONMENTS = {
-    "environment-default.yaml": {
-        "name": "default",
-        "channels": ["conda-forge", "defaults"],
+    "environment-dask.yaml": {
+        "name": "dask",
+        "channels": ["conda-forge"],
         "dependencies": [
-            "python=3.8",
+            "python",
             "ipykernel",
             "ipywidgets",
-            "dask==2.30.0",
-            "distributed==2.30.1",
-            "dask-gateway=0.9.0",
+            "python-graphviz",
+            "dask ==2.30.0",
+            "distributed ==2.30.1",
+            "dask-gateway ==0.9.0",
             "numpy",
             "numba",
             "pandas",
-            "cdsdashboards-singleuser",
         ],
-    }
+    },
+    "environment-dashboard.yaml": {
+        "name": "dashboard",
+        "channels": ["conda-forge"],
+        "dependencies": [
+            "python",
+            "ipykernel",
+            "ipywidgets >=7.6",
+            "param",
+            "python-graphviz",
+            "matplotlib >=3.3.4",
+            "panel >=0.10.3",
+            "voila >=0.2.7",
+            "streamlit >=0.76",
+            "dash >=1.19",
+            "cdsdashboards-singleuser >=0.5.6",
+        ],
+    },
 }
 
 
